import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/curran/8c131a74b85d0bb0246233de2cff3f52/raw/194c2fc143790b937c42bf086a5a44cb3c55340e/auto-mpg.csv';
const parseRow = (d) => {
  d.AvilaAdobe = +d.AvilaAdobe;
  d.Firehouse = +d.Firehouse;
  d.ChineseAmerican = +d.ChineseAmerican;
  d.AmericaTropical = +d.AmericaTropical;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.ChineseAmerican;
const yValue = (d) => d.AmericaTropical;
const rxValue = (d) => d.AvilaAdobe;
const ryValue = (d) => d.Firehouse;
const speciesValue = (d) => d.year;
const colorValue = d => d.year;
const colorLabel = 'Year';


const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Americatropical);
  const y = yValue((d) => d.AvilaAdobe);
  const marker = (d) => {
        	switch(d){
            case '2014':
              return 'pink';
            case '2015':
              return 'green';
            default:
              return '2016';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.AmericaTropical),
          y: yValue((d) => d.AvilaAdobe),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.AmericaTropical)
    .yValue((d) => d.AvilaAdobe)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);





//Defining the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));

     
    
  
  const columns = [
    'AmericaTropical',
    'Firehouse',
    'ChineseAmerican',
    'AvilaAdobe',
  ];

  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]); 
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("Museum Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

   
// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("2014").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("2015").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("2016").style("font-size", "20px").attr("alignment-baseline","middle")
  
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Avila Adobe");
    
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "pink")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "black")
   // plot AmericaTropical on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("America Tropical");
     // plot Firehouse on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Firehouse");
     // plot ChineseAmerican on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("Chinese American");
     // plot AvilaAdobe on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
      		.text("AvilaAdobe");
    i++;
  }, 3000);// every 3 seconds change the visualization
};
main();



